# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from sonatype_iq_api_client.models.policy_evaluation_result import PolicyEvaluationResult
from typing import Optional, Set
from typing_extensions import Self

class ApiReportResultsDTO(BaseModel):
    """
    ApiReportResultsDTO
    """ # noqa: E501
    application_id: Optional[StrictStr] = Field(default=None, alias="applicationId")
    commit_hash: Optional[StrictStr] = Field(default=None, alias="commitHash")
    embeddable_report_html_url: Optional[StrictStr] = Field(default=None, alias="embeddableReportHtmlUrl")
    evaluation_date: Optional[datetime] = Field(default=None, alias="evaluationDate")
    is_for_monitoring: Optional[StrictBool] = Field(default=None, alias="isForMonitoring")
    is_reevaluation: Optional[StrictBool] = Field(default=None, alias="isReevaluation")
    latest_report_html_url: Optional[StrictStr] = Field(default=None, alias="latestReportHtmlUrl")
    policy_evaluation_id: Optional[StrictStr] = Field(default=None, alias="policyEvaluationId")
    policy_evaluation_result: Optional[PolicyEvaluationResult] = Field(default=None, alias="policyEvaluationResult")
    report_data_url: Optional[StrictStr] = Field(default=None, alias="reportDataUrl")
    report_html_url: Optional[StrictStr] = Field(default=None, alias="reportHtmlUrl")
    report_pdf_url: Optional[StrictStr] = Field(default=None, alias="reportPdfUrl")
    scan_id: Optional[StrictStr] = Field(default=None, alias="scanId")
    scan_trigger_internal: Optional[StrictBool] = Field(default=None, alias="scanTriggerInternal")
    scan_trigger_type: Optional[StrictStr] = Field(default=None, alias="scanTriggerType")
    scan_trigger_type_display_name: Optional[StrictStr] = Field(default=None, alias="scanTriggerTypeDisplayName")
    scanner_version: Optional[StrictStr] = Field(default=None, alias="scannerVersion")
    stage: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["applicationId", "commitHash", "embeddableReportHtmlUrl", "evaluationDate", "isForMonitoring", "isReevaluation", "latestReportHtmlUrl", "policyEvaluationId", "policyEvaluationResult", "reportDataUrl", "reportHtmlUrl", "reportPdfUrl", "scanId", "scanTriggerInternal", "scanTriggerType", "scanTriggerTypeDisplayName", "scannerVersion", "stage"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiReportResultsDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of policy_evaluation_result
        if self.policy_evaluation_result:
            _dict['policyEvaluationResult'] = self.policy_evaluation_result.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiReportResultsDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "applicationId": obj.get("applicationId"),
            "commitHash": obj.get("commitHash"),
            "embeddableReportHtmlUrl": obj.get("embeddableReportHtmlUrl"),
            "evaluationDate": obj.get("evaluationDate"),
            "isForMonitoring": obj.get("isForMonitoring"),
            "isReevaluation": obj.get("isReevaluation"),
            "latestReportHtmlUrl": obj.get("latestReportHtmlUrl"),
            "policyEvaluationId": obj.get("policyEvaluationId"),
            "policyEvaluationResult": PolicyEvaluationResult.from_dict(obj["policyEvaluationResult"]) if obj.get("policyEvaluationResult") is not None else None,
            "reportDataUrl": obj.get("reportDataUrl"),
            "reportHtmlUrl": obj.get("reportHtmlUrl"),
            "reportPdfUrl": obj.get("reportPdfUrl"),
            "scanId": obj.get("scanId"),
            "scanTriggerInternal": obj.get("scanTriggerInternal"),
            "scanTriggerType": obj.get("scanTriggerType"),
            "scanTriggerTypeDisplayName": obj.get("scanTriggerTypeDisplayName"),
            "scannerVersion": obj.get("scannerVersion"),
            "stage": obj.get("stage")
        })
        return _obj





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr, field_validator
from typing import List, Optional
from typing_extensions import Annotated
from sonatype_iq_api_client.models.api_component_dtov2 import ApiComponentDTOV2
from sonatype_iq_api_client.models.api_component_details_request_dtov2 import ApiComponentDetailsRequestDTOV2
from sonatype_iq_api_client.models.api_component_details_result_dtov2 import ApiComponentDetailsResultDTOV2
from sonatype_iq_api_client.models.api_component_or_purl_identifier_dtov2 import ApiComponentOrPurlIdentifierDTOV2
from sonatype_iq_api_client.models.get_suggested_remediation_for_component200_response import GetSuggestedRemediationForComponent200Response

from sonatype_iq_api_client.api_client import ApiClient, RequestSerialized
from sonatype_iq_api_client.api_response import ApiResponse
from sonatype_iq_api_client.rest import RESTResponseType


class ComponentsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def delete_component_label(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Possible values: application or organization")],
        internal_owner_id: Annotated[StrictStr, Field(description="Possible values : applicationId or organizationId")],
        component_hash: Annotated[StrictStr, Field(description="Enter the SHA1 hash of the component.")],
        label_name: Annotated[StrictStr, Field(description="Enter the label name to un-assign from this component.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """delete_component_label

        Use this method to un-assign a label from a component.

        :param owner_type: Possible values: application or organization (required)
        :type owner_type: str
        :param internal_owner_id: Possible values : applicationId or organizationId (required)
        :type internal_owner_id: str
        :param component_hash: Enter the SHA1 hash of the component. (required)
        :type component_hash: str
        :param label_name: Enter the label name to un-assign from this component. (required)
        :type label_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_component_label_serialize(
            owner_type=owner_type,
            internal_owner_id=internal_owner_id,
            component_hash=component_hash,
            label_name=label_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_component_label_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Possible values: application or organization")],
        internal_owner_id: Annotated[StrictStr, Field(description="Possible values : applicationId or organizationId")],
        component_hash: Annotated[StrictStr, Field(description="Enter the SHA1 hash of the component.")],
        label_name: Annotated[StrictStr, Field(description="Enter the label name to un-assign from this component.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """delete_component_label

        Use this method to un-assign a label from a component.

        :param owner_type: Possible values: application or organization (required)
        :type owner_type: str
        :param internal_owner_id: Possible values : applicationId or organizationId (required)
        :type internal_owner_id: str
        :param component_hash: Enter the SHA1 hash of the component. (required)
        :type component_hash: str
        :param label_name: Enter the label name to un-assign from this component. (required)
        :type label_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_component_label_serialize(
            owner_type=owner_type,
            internal_owner_id=internal_owner_id,
            component_hash=component_hash,
            label_name=label_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_component_label_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Possible values: application or organization")],
        internal_owner_id: Annotated[StrictStr, Field(description="Possible values : applicationId or organizationId")],
        component_hash: Annotated[StrictStr, Field(description="Enter the SHA1 hash of the component.")],
        label_name: Annotated[StrictStr, Field(description="Enter the label name to un-assign from this component.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """delete_component_label

        Use this method to un-assign a label from a component.

        :param owner_type: Possible values: application or organization (required)
        :type owner_type: str
        :param internal_owner_id: Possible values : applicationId or organizationId (required)
        :type internal_owner_id: str
        :param component_hash: Enter the SHA1 hash of the component. (required)
        :type component_hash: str
        :param label_name: Enter the label name to un-assign from this component. (required)
        :type label_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_component_label_serialize(
            owner_type=owner_type,
            internal_owner_id=internal_owner_id,
            component_hash=component_hash,
            label_name=label_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_component_label_serialize(
        self,
        owner_type,
        internal_owner_id,
        component_hash,
        label_name,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if internal_owner_id is not None:
            _path_params['internalOwnerId'] = internal_owner_id
        if component_hash is not None:
            _path_params['componentHash'] = component_hash
        if label_name is not None:
            _path_params['labelName'] = label_name
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/v2/components/{componentHash}/labels/{labelName}/{ownerType}s/{internalOwnerId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_component_details(
        self,
        api_component_details_request_dtov2: Annotated[ApiComponentDetailsRequestDTOV2, Field(description="You can retrieve component data in any one of the 3 ways via: 1. Component identifier 2. Package URL 3. Hash")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiComponentDetailsResultDTOV2:
        """get_component_details

        Use this method to retrieve data related to a component.

        :param api_component_details_request_dtov2: You can retrieve component data in any one of the 3 ways via: 1. Component identifier 2. Package URL 3. Hash (required)
        :type api_component_details_request_dtov2: ApiComponentDetailsRequestDTOV2
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_component_details_serialize(
            api_component_details_request_dtov2=api_component_details_request_dtov2,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiComponentDetailsResultDTOV2",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_component_details_with_http_info(
        self,
        api_component_details_request_dtov2: Annotated[ApiComponentDetailsRequestDTOV2, Field(description="You can retrieve component data in any one of the 3 ways via: 1. Component identifier 2. Package URL 3. Hash")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiComponentDetailsResultDTOV2]:
        """get_component_details

        Use this method to retrieve data related to a component.

        :param api_component_details_request_dtov2: You can retrieve component data in any one of the 3 ways via: 1. Component identifier 2. Package URL 3. Hash (required)
        :type api_component_details_request_dtov2: ApiComponentDetailsRequestDTOV2
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_component_details_serialize(
            api_component_details_request_dtov2=api_component_details_request_dtov2,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiComponentDetailsResultDTOV2",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_component_details_without_preload_content(
        self,
        api_component_details_request_dtov2: Annotated[ApiComponentDetailsRequestDTOV2, Field(description="You can retrieve component data in any one of the 3 ways via: 1. Component identifier 2. Package URL 3. Hash")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_component_details

        Use this method to retrieve data related to a component.

        :param api_component_details_request_dtov2: You can retrieve component data in any one of the 3 ways via: 1. Component identifier 2. Package URL 3. Hash (required)
        :type api_component_details_request_dtov2: ApiComponentDetailsRequestDTOV2
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_component_details_serialize(
            api_component_details_request_dtov2=api_component_details_request_dtov2,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiComponentDetailsResultDTOV2",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_component_details_serialize(
        self,
        api_component_details_request_dtov2,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_component_details_request_dtov2 is not None:
            _body_params = api_component_details_request_dtov2


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v2/components/details',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_component_versions(
        self,
        api_component_or_purl_identifier_dtov2: Annotated[Optional[ApiComponentOrPurlIdentifierDTOV2], Field(description="Possible values: Component identifier or packageURL (pURL) identifier in the correct format. Use a-name for JavaScript components.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[str]:
        """get_component_versions

        Use this method to retrieve all known versions of a component.

        :param api_component_or_purl_identifier_dtov2: Possible values: Component identifier or packageURL (pURL) identifier in the correct format. Use a-name for JavaScript components.
        :type api_component_or_purl_identifier_dtov2: ApiComponentOrPurlIdentifierDTOV2
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_component_versions_serialize(
            api_component_or_purl_identifier_dtov2=api_component_or_purl_identifier_dtov2,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[str]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_component_versions_with_http_info(
        self,
        api_component_or_purl_identifier_dtov2: Annotated[Optional[ApiComponentOrPurlIdentifierDTOV2], Field(description="Possible values: Component identifier or packageURL (pURL) identifier in the correct format. Use a-name for JavaScript components.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[str]]:
        """get_component_versions

        Use this method to retrieve all known versions of a component.

        :param api_component_or_purl_identifier_dtov2: Possible values: Component identifier or packageURL (pURL) identifier in the correct format. Use a-name for JavaScript components.
        :type api_component_or_purl_identifier_dtov2: ApiComponentOrPurlIdentifierDTOV2
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_component_versions_serialize(
            api_component_or_purl_identifier_dtov2=api_component_or_purl_identifier_dtov2,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[str]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_component_versions_without_preload_content(
        self,
        api_component_or_purl_identifier_dtov2: Annotated[Optional[ApiComponentOrPurlIdentifierDTOV2], Field(description="Possible values: Component identifier or packageURL (pURL) identifier in the correct format. Use a-name for JavaScript components.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_component_versions

        Use this method to retrieve all known versions of a component.

        :param api_component_or_purl_identifier_dtov2: Possible values: Component identifier or packageURL (pURL) identifier in the correct format. Use a-name for JavaScript components.
        :type api_component_or_purl_identifier_dtov2: ApiComponentOrPurlIdentifierDTOV2
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_component_versions_serialize(
            api_component_or_purl_identifier_dtov2=api_component_or_purl_identifier_dtov2,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[str]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_component_versions_serialize(
        self,
        api_component_or_purl_identifier_dtov2,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_component_or_purl_identifier_dtov2 is not None:
            _body_params = api_component_or_purl_identifier_dtov2


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v2/components/versions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_suggested_remediation_for_component(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Possible values: application, organization, repository. ")],
        owner_id: Annotated[StrictStr, Field(description="Possible values: applicationId, organizationId or repositoryId.")],
        stage_id: Annotated[Optional[StrictStr], Field(description="Enter the stageId to obtain next-non-failing and next-non-failing-with-dependencies remediation types in the response. Possible values are develop, build, stage-release, release and operate.")] = None,
        identification_source: Annotated[Optional[StrictStr], Field(description="Enter the identification source if you want the remediation result based on third-party scan information (non-Sonatype). The identification source can be obtained from the Component Details Page in the UI.")] = None,
        scan_id: Annotated[Optional[StrictStr], Field(description="Enter the scanId (reportId) if you want the remediation result based on third-party scan information (non-Sonatype).")] = None,
        include_parent_remediation: Annotated[Optional[StrictBool], Field(description="Enter true if you want to include parent remediation for transitive dependency in the response based on your application policy scan.")] = None,
        api_component_dtov2: Optional[ApiComponentDTOV2] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GetSuggestedRemediationForComponent200Response:
        """get_suggested_remediation_for_component

        Use this method to obtain remediation suggestions for policy violations on a component basis. Remediations obtained from this method are same as those appearing on the Component Details Page in the UI.

        :param owner_type: Possible values: application, organization, repository.  (required)
        :type owner_type: str
        :param owner_id: Possible values: applicationId, organizationId or repositoryId. (required)
        :type owner_id: str
        :param stage_id: Enter the stageId to obtain next-non-failing and next-non-failing-with-dependencies remediation types in the response. Possible values are develop, build, stage-release, release and operate.
        :type stage_id: str
        :param identification_source: Enter the identification source if you want the remediation result based on third-party scan information (non-Sonatype). The identification source can be obtained from the Component Details Page in the UI.
        :type identification_source: str
        :param scan_id: Enter the scanId (reportId) if you want the remediation result based on third-party scan information (non-Sonatype).
        :type scan_id: str
        :param include_parent_remediation: Enter true if you want to include parent remediation for transitive dependency in the response based on your application policy scan.
        :type include_parent_remediation: bool
        :param api_component_dtov2:
        :type api_component_dtov2: ApiComponentDTOV2
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_suggested_remediation_for_component_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            stage_id=stage_id,
            identification_source=identification_source,
            scan_id=scan_id,
            include_parent_remediation=include_parent_remediation,
            api_component_dtov2=api_component_dtov2,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetSuggestedRemediationForComponent200Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_suggested_remediation_for_component_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Possible values: application, organization, repository. ")],
        owner_id: Annotated[StrictStr, Field(description="Possible values: applicationId, organizationId or repositoryId.")],
        stage_id: Annotated[Optional[StrictStr], Field(description="Enter the stageId to obtain next-non-failing and next-non-failing-with-dependencies remediation types in the response. Possible values are develop, build, stage-release, release and operate.")] = None,
        identification_source: Annotated[Optional[StrictStr], Field(description="Enter the identification source if you want the remediation result based on third-party scan information (non-Sonatype). The identification source can be obtained from the Component Details Page in the UI.")] = None,
        scan_id: Annotated[Optional[StrictStr], Field(description="Enter the scanId (reportId) if you want the remediation result based on third-party scan information (non-Sonatype).")] = None,
        include_parent_remediation: Annotated[Optional[StrictBool], Field(description="Enter true if you want to include parent remediation for transitive dependency in the response based on your application policy scan.")] = None,
        api_component_dtov2: Optional[ApiComponentDTOV2] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GetSuggestedRemediationForComponent200Response]:
        """get_suggested_remediation_for_component

        Use this method to obtain remediation suggestions for policy violations on a component basis. Remediations obtained from this method are same as those appearing on the Component Details Page in the UI.

        :param owner_type: Possible values: application, organization, repository.  (required)
        :type owner_type: str
        :param owner_id: Possible values: applicationId, organizationId or repositoryId. (required)
        :type owner_id: str
        :param stage_id: Enter the stageId to obtain next-non-failing and next-non-failing-with-dependencies remediation types in the response. Possible values are develop, build, stage-release, release and operate.
        :type stage_id: str
        :param identification_source: Enter the identification source if you want the remediation result based on third-party scan information (non-Sonatype). The identification source can be obtained from the Component Details Page in the UI.
        :type identification_source: str
        :param scan_id: Enter the scanId (reportId) if you want the remediation result based on third-party scan information (non-Sonatype).
        :type scan_id: str
        :param include_parent_remediation: Enter true if you want to include parent remediation for transitive dependency in the response based on your application policy scan.
        :type include_parent_remediation: bool
        :param api_component_dtov2:
        :type api_component_dtov2: ApiComponentDTOV2
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_suggested_remediation_for_component_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            stage_id=stage_id,
            identification_source=identification_source,
            scan_id=scan_id,
            include_parent_remediation=include_parent_remediation,
            api_component_dtov2=api_component_dtov2,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetSuggestedRemediationForComponent200Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_suggested_remediation_for_component_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Possible values: application, organization, repository. ")],
        owner_id: Annotated[StrictStr, Field(description="Possible values: applicationId, organizationId or repositoryId.")],
        stage_id: Annotated[Optional[StrictStr], Field(description="Enter the stageId to obtain next-non-failing and next-non-failing-with-dependencies remediation types in the response. Possible values are develop, build, stage-release, release and operate.")] = None,
        identification_source: Annotated[Optional[StrictStr], Field(description="Enter the identification source if you want the remediation result based on third-party scan information (non-Sonatype). The identification source can be obtained from the Component Details Page in the UI.")] = None,
        scan_id: Annotated[Optional[StrictStr], Field(description="Enter the scanId (reportId) if you want the remediation result based on third-party scan information (non-Sonatype).")] = None,
        include_parent_remediation: Annotated[Optional[StrictBool], Field(description="Enter true if you want to include parent remediation for transitive dependency in the response based on your application policy scan.")] = None,
        api_component_dtov2: Optional[ApiComponentDTOV2] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_suggested_remediation_for_component

        Use this method to obtain remediation suggestions for policy violations on a component basis. Remediations obtained from this method are same as those appearing on the Component Details Page in the UI.

        :param owner_type: Possible values: application, organization, repository.  (required)
        :type owner_type: str
        :param owner_id: Possible values: applicationId, organizationId or repositoryId. (required)
        :type owner_id: str
        :param stage_id: Enter the stageId to obtain next-non-failing and next-non-failing-with-dependencies remediation types in the response. Possible values are develop, build, stage-release, release and operate.
        :type stage_id: str
        :param identification_source: Enter the identification source if you want the remediation result based on third-party scan information (non-Sonatype). The identification source can be obtained from the Component Details Page in the UI.
        :type identification_source: str
        :param scan_id: Enter the scanId (reportId) if you want the remediation result based on third-party scan information (non-Sonatype).
        :type scan_id: str
        :param include_parent_remediation: Enter true if you want to include parent remediation for transitive dependency in the response based on your application policy scan.
        :type include_parent_remediation: bool
        :param api_component_dtov2:
        :type api_component_dtov2: ApiComponentDTOV2
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_suggested_remediation_for_component_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            stage_id=stage_id,
            identification_source=identification_source,
            scan_id=scan_id,
            include_parent_remediation=include_parent_remediation,
            api_component_dtov2=api_component_dtov2,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetSuggestedRemediationForComponent200Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_suggested_remediation_for_component_serialize(
        self,
        owner_type,
        owner_id,
        stage_id,
        identification_source,
        scan_id,
        include_parent_remediation,
        api_component_dtov2,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        # process the query parameters
        if stage_id is not None:
            
            _query_params.append(('stageId', stage_id))
            
        if identification_source is not None:
            
            _query_params.append(('identificationSource', identification_source))
            
        if scan_id is not None:
            
            _query_params.append(('scanId', scan_id))
            
        if include_parent_remediation is not None:
            
            _query_params.append(('includeParentRemediation', include_parent_remediation))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_component_dtov2 is not None:
            _body_params = api_component_dtov2


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v2/components/remediation/{ownerType}/{ownerId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def set_component_label(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Possible values: application or organization")],
        internal_owner_id: Annotated[StrictStr, Field(description="Possible values : applicationId or organizationId")],
        component_hash: Annotated[StrictStr, Field(description="Enter the SHA1 hash of the component.")],
        label_name: Annotated[StrictStr, Field(description="Enter the label name to assign to this component.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """set_component_label

        Use this method to assign an existing label to a component.

        :param owner_type: Possible values: application or organization (required)
        :type owner_type: str
        :param internal_owner_id: Possible values : applicationId or organizationId (required)
        :type internal_owner_id: str
        :param component_hash: Enter the SHA1 hash of the component. (required)
        :type component_hash: str
        :param label_name: Enter the label name to assign to this component. (required)
        :type label_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._set_component_label_serialize(
            owner_type=owner_type,
            internal_owner_id=internal_owner_id,
            component_hash=component_hash,
            label_name=label_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def set_component_label_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Possible values: application or organization")],
        internal_owner_id: Annotated[StrictStr, Field(description="Possible values : applicationId or organizationId")],
        component_hash: Annotated[StrictStr, Field(description="Enter the SHA1 hash of the component.")],
        label_name: Annotated[StrictStr, Field(description="Enter the label name to assign to this component.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """set_component_label

        Use this method to assign an existing label to a component.

        :param owner_type: Possible values: application or organization (required)
        :type owner_type: str
        :param internal_owner_id: Possible values : applicationId or organizationId (required)
        :type internal_owner_id: str
        :param component_hash: Enter the SHA1 hash of the component. (required)
        :type component_hash: str
        :param label_name: Enter the label name to assign to this component. (required)
        :type label_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._set_component_label_serialize(
            owner_type=owner_type,
            internal_owner_id=internal_owner_id,
            component_hash=component_hash,
            label_name=label_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def set_component_label_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Possible values: application or organization")],
        internal_owner_id: Annotated[StrictStr, Field(description="Possible values : applicationId or organizationId")],
        component_hash: Annotated[StrictStr, Field(description="Enter the SHA1 hash of the component.")],
        label_name: Annotated[StrictStr, Field(description="Enter the label name to assign to this component.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """set_component_label

        Use this method to assign an existing label to a component.

        :param owner_type: Possible values: application or organization (required)
        :type owner_type: str
        :param internal_owner_id: Possible values : applicationId or organizationId (required)
        :type internal_owner_id: str
        :param component_hash: Enter the SHA1 hash of the component. (required)
        :type component_hash: str
        :param label_name: Enter the label name to assign to this component. (required)
        :type label_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._set_component_label_serialize(
            owner_type=owner_type,
            internal_owner_id=internal_owner_id,
            component_hash=component_hash,
            label_name=label_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _set_component_label_serialize(
        self,
        owner_type,
        internal_owner_id,
        component_hash,
        label_name,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if internal_owner_id is not None:
            _path_params['internalOwnerId'] = internal_owner_id
        if component_hash is not None:
            _path_params['componentHash'] = component_hash
        if label_name is not None:
            _path_params['labelName'] = label_name
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v2/components/{componentHash}/labels/{labelName}/{ownerType}s/{internalOwnerId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from sonatype_iq_api_client.models.component_identifier import ComponentIdentifier
from typing import Optional, Set
from typing_extensions import Self

class PrioritizedComponent(BaseModel):
    """
    List of items for the current page
    """ # noqa: E501
    action: Optional[StrictStr] = None
    component_hash: Optional[StrictStr] = Field(default=None, alias="componentHash")
    component_identifier: Optional[ComponentIdentifier] = Field(default=None, alias="componentIdentifier")
    dependency_type: Optional[StrictStr] = Field(default=None, alias="dependencyType")
    display_name: Optional[StrictStr] = Field(default=None, alias="displayName")
    has_auto_waiver: Optional[StrictBool] = Field(default=None, alias="hasAutoWaiver")
    has_expired_waiver: Optional[StrictBool] = Field(default=None, alias="hasExpiredWaiver")
    has_fail_action_on_component: Optional[StrictBool] = Field(default=None, alias="hasFailActionOnComponent")
    has_same_violations_on_main: Optional[StrictBool] = Field(default=None, alias="hasSameViolationsOnMain")
    has_soon_to_expire_waiver: Optional[StrictBool] = Field(default=None, alias="hasSoonToExpireWaiver")
    highest_reachable_threat: Optional[StrictInt] = Field(default=None, alias="highestReachableThreat")
    highest_threat: Optional[StrictInt] = Field(default=None, alias="highestThreat")
    highest_threat_policy_constraint_name: Optional[StrictStr] = Field(default=None, alias="highestThreatPolicyConstraintName")
    highest_threat_policy_name: Optional[StrictStr] = Field(default=None, alias="highestThreatPolicyName")
    is_all_violations_waived: Optional[StrictBool] = Field(default=None, alias="isAllViolationsWaived")
    priority: Optional[StrictInt] = None
    remediation_type: Optional[StrictStr] = Field(default=None, alias="remediationType")
    remediation_version: Optional[StrictStr] = Field(default=None, alias="remediationVersion")
    security_reachable: Optional[StrictBool] = Field(default=None, alias="securityReachable")
    waived_violations_count: Optional[StrictInt] = Field(default=None, alias="waivedViolationsCount")
    waiver_expiration_details: Optional[StrictStr] = Field(default=None, alias="waiverExpirationDetails")
    __properties: ClassVar[List[str]] = ["action", "componentHash", "componentIdentifier", "dependencyType", "displayName", "hasAutoWaiver", "hasExpiredWaiver", "hasFailActionOnComponent", "hasSameViolationsOnMain", "hasSoonToExpireWaiver", "highestReachableThreat", "highestThreat", "highestThreatPolicyConstraintName", "highestThreatPolicyName", "isAllViolationsWaived", "priority", "remediationType", "remediationVersion", "securityReachable", "waivedViolationsCount", "waiverExpirationDetails"]

    @field_validator('remediation_type')
    def remediation_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['next-no-violations', 'next-non-failing', 'next-no-violations-with-dependencies', 'next-non-failing-with-dependencies', 'inner-source-latest-non-breaking', 'inner-source-latest', 'recommended-non-breaking', 'recommended-non-breaking-with-dependencies']):
            raise ValueError("must be one of enum values ('next-no-violations', 'next-non-failing', 'next-no-violations-with-dependencies', 'next-non-failing-with-dependencies', 'inner-source-latest-non-breaking', 'inner-source-latest', 'recommended-non-breaking', 'recommended-non-breaking-with-dependencies')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PrioritizedComponent from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of component_identifier
        if self.component_identifier:
            _dict['componentIdentifier'] = self.component_identifier.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PrioritizedComponent from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "action": obj.get("action"),
            "componentHash": obj.get("componentHash"),
            "componentIdentifier": ComponentIdentifier.from_dict(obj["componentIdentifier"]) if obj.get("componentIdentifier") is not None else None,
            "dependencyType": obj.get("dependencyType"),
            "displayName": obj.get("displayName"),
            "hasAutoWaiver": obj.get("hasAutoWaiver"),
            "hasExpiredWaiver": obj.get("hasExpiredWaiver"),
            "hasFailActionOnComponent": obj.get("hasFailActionOnComponent"),
            "hasSameViolationsOnMain": obj.get("hasSameViolationsOnMain"),
            "hasSoonToExpireWaiver": obj.get("hasSoonToExpireWaiver"),
            "highestReachableThreat": obj.get("highestReachableThreat"),
            "highestThreat": obj.get("highestThreat"),
            "highestThreatPolicyConstraintName": obj.get("highestThreatPolicyConstraintName"),
            "highestThreatPolicyName": obj.get("highestThreatPolicyName"),
            "isAllViolationsWaived": obj.get("isAllViolationsWaived"),
            "priority": obj.get("priority"),
            "remediationType": obj.get("remediationType"),
            "remediationVersion": obj.get("remediationVersion"),
            "securityReachable": obj.get("securityReachable"),
            "waivedViolationsCount": obj.get("waivedViolationsCount"),
            "waiverExpirationDetails": obj.get("waiverExpirationDetails")
        })
        return _obj





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.search_result_item_dto import SearchResultItemDTO

class TestSearchResultItemDTO(unittest.TestCase):
    """SearchResultItemDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchResultItemDTO:
        """Test SearchResultItemDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchResultItemDTO`
        """
        model = SearchResultItemDTO()
        if include_optional:
            return SearchResultItemDTO(
                application_category_color = '',
                application_category_description = '',
                application_category_id = '',
                application_category_name = '',
                application_id = '',
                application_name = '',
                application_public_id = '',
                application_version = '',
                component_hash = '',
                component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                    coordinates = {
                        'key' : ''
                        }, 
                    format = '', ),
                component_label_color = '',
                component_label_description = '',
                component_label_id = '',
                component_label_name = '',
                component_name = '',
                item_type = '',
                organization_id = '',
                organization_name = '',
                policy_evaluation_stage = '',
                policy_id = '',
                policy_name = '',
                policy_threat_category = '',
                policy_threat_level = 56,
                report_id = '',
                result_index = 56,
                sbom_specification = '',
                vulnerability_description = '',
                vulnerability_id = '',
                vulnerability_status = ''
            )
        else:
            return SearchResultItemDTO(
        )
        """

    def testSearchResultItemDTO(self):
        """Test SearchResultItemDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from sonatype_iq_api_client.models.search_result_item_dto import SearchResultItemDTO
from typing import Optional, Set
from typing_extensions import Self

class GroupingByDTO(BaseModel):
    """
    GroupingByDTO
    """ # noqa: E501
    additional_info: Optional[StrictStr] = Field(default=None, alias="additionalInfo")
    group_by: Optional[StrictStr] = Field(default=None, alias="groupBy")
    group_identifier: Optional[StrictStr] = Field(default=None, alias="groupIdentifier")
    search_result_item_dtos: Optional[List[SearchResultItemDTO]] = Field(default=None, alias="searchResultItemDTOS")
    __properties: ClassVar[List[str]] = ["additionalInfo", "groupBy", "groupIdentifier", "searchResultItemDTOS"]

    @field_validator('group_identifier')
    def group_identifier_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['itemType', 'organizationId', 'organizationName', 'applicationId', 'applicationName', 'applicationPublicId', 'policyEvaluationStage', 'applicationVersion', 'reportId', 'componentHash', 'componentFormat', 'componentName', 'componentCoordinate', 'vulnerabilityId', 'vulnerabilitySeverity', 'vulnerabilityStatus', 'vulnerabilityDescription', 'applicationCategoryId', 'applicationCategoryName', 'applicationCategoryColor', 'applicationCategoryDescription', 'componentLabelId', 'componentLabelName', 'componentLabelColor', 'componentLabelDescription', 'policyId', 'policyName', 'policyThreatCategory', 'policyThreatLevel', 'parentOrganizationName', 'parentOrganizationId', 'sbomSpecification']):
            raise ValueError("must be one of enum values ('itemType', 'organizationId', 'organizationName', 'applicationId', 'applicationName', 'applicationPublicId', 'policyEvaluationStage', 'applicationVersion', 'reportId', 'componentHash', 'componentFormat', 'componentName', 'componentCoordinate', 'vulnerabilityId', 'vulnerabilitySeverity', 'vulnerabilityStatus', 'vulnerabilityDescription', 'applicationCategoryId', 'applicationCategoryName', 'applicationCategoryColor', 'applicationCategoryDescription', 'componentLabelId', 'componentLabelName', 'componentLabelColor', 'componentLabelDescription', 'policyId', 'policyName', 'policyThreatCategory', 'policyThreatLevel', 'parentOrganizationName', 'parentOrganizationId', 'sbomSpecification')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GroupingByDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in search_result_item_dtos (list)
        _items = []
        if self.search_result_item_dtos:
            for _item_search_result_item_dtos in self.search_result_item_dtos:
                if _item_search_result_item_dtos:
                    _items.append(_item_search_result_item_dtos.to_dict())
            _dict['searchResultItemDTOS'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GroupingByDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "additionalInfo": obj.get("additionalInfo"),
            "groupBy": obj.get("groupBy"),
            "groupIdentifier": obj.get("groupIdentifier"),
            "searchResultItemDTOS": [SearchResultItemDTO.from_dict(_item) for _item in obj["searchResultItemDTOS"]] if obj.get("searchResultItemDTOS") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.applications_api import ApplicationsApi


class TestApplicationsApi(unittest.TestCase):
    """ApplicationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationsApi()

    def tearDown(self) -> None:
        pass

    def test_add_application(self) -> None:
        """Test case for add_application

        """
        pass

    def test_clone_application(self) -> None:
        """Test case for clone_application

        """
        pass

    def test_delete_application(self) -> None:
        """Test case for delete_application

        """
        pass

    def test_get_application(self) -> None:
        """Test case for get_application

        """
        pass

    def test_get_applications(self) -> None:
        """Test case for get_applications

        """
        pass

    def test_get_applications_by_organization_id(self) -> None:
        """Test case for get_applications_by_organization_id

        """
        pass

    def test_move_application(self) -> None:
        """Test case for move_application

        """
        pass

    def test_update_application(self) -> None:
        """Test case for update_application

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from sonatype_iq_api_client.models.api_component_dtov2 import ApiComponentDTOV2
from sonatype_iq_api_client.models.api_component_policy_violation_list_dtov2 import ApiComponentPolicyViolationListDTOV2
from sonatype_iq_api_client.models.api_component_project_data_dto import ApiComponentProjectDataDTO
from sonatype_iq_api_client.models.api_license_data_dto import ApiLicenseDataDTO
from sonatype_iq_api_client.models.api_security_data_dto import ApiSecurityDataDTO
from typing import Optional, Set
from typing_extensions import Self

class ApiComponentDetailsDTOV2(BaseModel):
    """
    ApiComponentDetailsDTOV2
    """ # noqa: E501
    catalog_date: Optional[StrictStr] = Field(default=None, alias="catalogDate")
    component: Optional[ApiComponentDTOV2] = None
    hygiene_rating: Optional[StrictStr] = Field(default=None, alias="hygieneRating")
    integrity_rating: Optional[StrictStr] = Field(default=None, alias="integrityRating")
    license_data: Optional[ApiLicenseDataDTO] = Field(default=None, alias="licenseData")
    match_state: Optional[StrictStr] = Field(default=None, alias="matchState")
    policy_data: Optional[ApiComponentPolicyViolationListDTOV2] = Field(default=None, alias="policyData")
    project_data: Optional[ApiComponentProjectDataDTO] = Field(default=None, alias="projectData")
    relative_popularity: Optional[StrictInt] = Field(default=None, alias="relativePopularity")
    security_data: Optional[ApiSecurityDataDTO] = Field(default=None, alias="securityData")
    __properties: ClassVar[List[str]] = ["catalogDate", "component", "hygieneRating", "integrityRating", "licenseData", "matchState", "policyData", "projectData", "relativePopularity", "securityData"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiComponentDetailsDTOV2 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of component
        if self.component:
            _dict['component'] = self.component.to_dict()
        # override the default output from pydantic by calling `to_dict()` of license_data
        if self.license_data:
            _dict['licenseData'] = self.license_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of policy_data
        if self.policy_data:
            _dict['policyData'] = self.policy_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of project_data
        if self.project_data:
            _dict['projectData'] = self.project_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of security_data
        if self.security_data:
            _dict['securityData'] = self.security_data.to_dict()
        # set to None if hygiene_rating (nullable) is None
        # and model_fields_set contains the field
        if self.hygiene_rating is None and "hygiene_rating" in self.model_fields_set:
            _dict['hygieneRating'] = None

        # set to None if integrity_rating (nullable) is None
        # and model_fields_set contains the field
        if self.integrity_rating is None and "integrity_rating" in self.model_fields_set:
            _dict['integrityRating'] = None

        # set to None if relative_popularity (nullable) is None
        # and model_fields_set contains the field
        if self.relative_popularity is None and "relative_popularity" in self.model_fields_set:
            _dict['relativePopularity'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiComponentDetailsDTOV2 from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "catalogDate": obj.get("catalogDate"),
            "component": ApiComponentDTOV2.from_dict(obj["component"]) if obj.get("component") is not None else None,
            "hygieneRating": obj.get("hygieneRating"),
            "integrityRating": obj.get("integrityRating"),
            "licenseData": ApiLicenseDataDTO.from_dict(obj["licenseData"]) if obj.get("licenseData") is not None else None,
            "matchState": obj.get("matchState"),
            "policyData": ApiComponentPolicyViolationListDTOV2.from_dict(obj["policyData"]) if obj.get("policyData") is not None else None,
            "projectData": ApiComponentProjectDataDTO.from_dict(obj["projectData"]) if obj.get("projectData") is not None else None,
            "relativePopularity": obj.get("relativePopularity"),
            "securityData": ApiSecurityDataDTO.from_dict(obj["securityData"]) if obj.get("securityData") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_report_policy_data_dtov2 import ApiReportPolicyDataDTOV2

class TestApiReportPolicyDataDTOV2(unittest.TestCase):
    """ApiReportPolicyDataDTOV2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiReportPolicyDataDTOV2:
        """Test ApiReportPolicyDataDTOV2
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiReportPolicyDataDTOV2`
        """
        model = ApiReportPolicyDataDTOV2()
        if include_optional:
            return ApiReportPolicyDataDTOV2(
                application = sonatype_iq_api_client.models.api_application_base_dto.ApiApplicationBaseDTO(
                    contact_user_name = '', 
                    id = '', 
                    name = '', 
                    organization_id = '', 
                    public_id = '', ),
                commit_hash = '',
                components = [
                    sonatype_iq_api_client.models.api_report_component_policy_violations_dtov2.ApiReportComponentPolicyViolationsDTOV2(
                        component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                            coordinates = {
                                'key' : ''
                                }, 
                            format = '', ), 
                        dependency_data = sonatype_iq_api_client.models.api_dependency_data_dto.ApiDependencyDataDTO(
                            direct_dependency = True, 
                            inner_source = True, 
                            inner_source_data = [
                                sonatype_iq_api_client.models.inner_source_data.InnerSourceData(
                                    inner_source_component_purl = '', 
                                    owner_application_id = '', 
                                    owner_application_name = '', )
                                ], 
                            parent_component_purls = [
                                ''
                                ], ), 
                        display_name = '', 
                        hash = '', 
                        match_state = '', 
                        original_purl = '', 
                        package_url = '', 
                        pathnames = [
                            ''
                            ], 
                        proprietary = True, 
                        sha256 = '', 
                        third_party = True, 
                        violations = [
                            sonatype_iq_api_client.models.api_report_policy_violation_dtov2.ApiReportPolicyViolationDTOV2(
                                constraints = [
                                    sonatype_iq_api_client.models.api_report_constraint_violation_dtov2.ApiReportConstraintViolationDTOV2(
                                        conditions = [
                                            sonatype_iq_api_client.models.api_report_constraint_condition_dtov2.ApiReportConstraintConditionDTOV2(
                                                condition_reason = '', 
                                                condition_summary = '', )
                                            ], 
                                        constraint_id = '', 
                                        constraint_name = '', )
                                    ], 
                                fix_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                grandfathered = True, 
                                legacy_violation = True, 
                                legacy_violation_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                open_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                policy_id = '', 
                                policy_name = '', 
                                policy_threat_category = '', 
                                policy_threat_level = 56, 
                                policy_violation_id = '', 
                                waive_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                waived = True, 
                                waived_with_auto_waiver = True, )
                            ], )
                    ],
                counts = {
                    'key' : 56
                    },
                initiator = '',
                report_time = 1.337,
                report_title = ''
            )
        else:
            return ApiReportPolicyDataDTOV2(
        )
        """

    def testApiReportPolicyDataDTOV2(self):
        """Test ApiReportPolicyDataDTOV2"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.policy_evaluation_result import PolicyEvaluationResult

class TestPolicyEvaluationResult(unittest.TestCase):
    """PolicyEvaluationResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PolicyEvaluationResult:
        """Test PolicyEvaluationResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PolicyEvaluationResult`
        """
        model = PolicyEvaluationResult()
        if include_optional:
            return PolicyEvaluationResult(
                affected_component_count = 56,
                alerts = [
                    sonatype_iq_api_client.models.policy_alert.PolicyAlert(
                        actions = [
                            sonatype_iq_api_client.models.action.Action(
                                action_type_id = '', 
                                target = '', 
                                target_type = '', )
                            ], 
                        trigger = sonatype_iq_api_client.models.policy_fact.PolicyFact(
                            component_facts = [
                                sonatype_iq_api_client.models.component_fact.ComponentFact(
                                    component_identifier = sonatype_iq_api_client.models.component_identifier.ComponentIdentifier(
                                        coordinates = {
                                            'key' : ''
                                            }, 
                                        format = '', ), 
                                    constraint_facts = [
                                        sonatype_iq_api_client.models.constraint_fact.ConstraintFact(
                                            condition_facts = [
                                                sonatype_iq_api_client.models.condition_fact.ConditionFact(
                                                    condition_index = 56, 
                                                    condition_type_id = '', 
                                                    reason = '', 
                                                    reference = sonatype_iq_api_client.models.trigger_reference.TriggerReference(
                                                        type = 'SECURITY_VULNERABILITY_REFID', 
                                                        value = '', ), 
                                                    summary = '', 
                                                    trigger_json = '', )
                                                ], 
                                            constraint_id = '', 
                                            constraint_name = '', 
                                            operator_name = '', )
                                        ], 
                                    display_name = sonatype_iq_api_client.models.component_display_name.ComponentDisplayName(
                                        name = '', 
                                        parts = [
                                            sonatype_iq_api_client.models.component_display_name_part.ComponentDisplayNamePart(
                                                field = '', 
                                                value = '', )
                                            ], ), 
                                    hash = '', 
                                    pathnames = [
                                        ''
                                        ], )
                                ], 
                            policy_id = '', 
                            policy_name = '', 
                            policy_violation_id = '', 
                            threat_level = 56, ), )
                    ],
                critical_component_count = 56,
                critical_policy_violation_count = 56,
                critical_sast_policy_violation_count = 56,
                grandfathered_policy_violation_count = 56,
                legacy_violation_count = 56,
                moderate_component_count = 56,
                moderate_policy_violation_count = 56,
                moderate_sast_policy_violation_count = 56,
                sast_alerts = [
                    sonatype_iq_api_client.models.policy_alert.PolicyAlert(
                        actions = [
                            sonatype_iq_api_client.models.action.Action(
                                action_type_id = '', 
                                target = '', 
                                target_type = '', )
                            ], 
                        trigger = sonatype_iq_api_client.models.policy_fact.PolicyFact(
                            component_facts = [
                                sonatype_iq_api_client.models.component_fact.ComponentFact(
                                    component_identifier = sonatype_iq_api_client.models.component_identifier.ComponentIdentifier(
                                        coordinates = {
                                            'key' : ''
                                            }, 
                                        format = '', ), 
                                    constraint_facts = [
                                        sonatype_iq_api_client.models.constraint_fact.ConstraintFact(
                                            condition_facts = [
                                                sonatype_iq_api_client.models.condition_fact.ConditionFact(
                                                    condition_index = 56, 
                                                    condition_type_id = '', 
                                                    reason = '', 
                                                    reference = sonatype_iq_api_client.models.trigger_reference.TriggerReference(
                                                        type = 'SECURITY_VULNERABILITY_REFID', 
                                                        value = '', ), 
                                                    summary = '', 
                                                    trigger_json = '', )
                                                ], 
                                            constraint_id = '', 
                                            constraint_name = '', 
                                            operator_name = '', )
                                        ], 
                                    display_name = sonatype_iq_api_client.models.component_display_name.ComponentDisplayName(
                                        name = '', 
                                        parts = [
                                            sonatype_iq_api_client.models.component_display_name_part.ComponentDisplayNamePart(
                                                field = '', 
                                                value = '', )
                                            ], ), 
                                    hash = '', 
                                    pathnames = [
                                        ''
                                        ], )
                                ], 
                            policy_id = '', 
                            policy_name = '', 
                            policy_violation_id = '', 
                            threat_level = 56, ), )
                    ],
                severe_component_count = 56,
                severe_policy_violation_count = 56,
                severe_sast_policy_violation_count = 56,
                total_component_count = 56,
                total_sast_finding_count = 56
            )
        else:
            return PolicyEvaluationResult(
        )
        """

    def testPolicyEvaluationResult(self):
        """Test PolicyEvaluationResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
